package pl8.extractor;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;

import ar.com.hjg.pngj.ImageInfo;
import ar.com.hjg.pngj.PngWriter;

public class TilesetSimple implements ITileset {

	private int[][] tileset;
	private final int tilesetWidth = 640;
	private final int tilesetHeight = 480 * 2;
	private final int bytesPerPixel = 4;

	private int posX = 0;
	private int posY = 0;

	public TilesetSimple() {
		this.tileset = new int[tilesetHeight][tilesetWidth * bytesPerPixel];
	}

	public void addTile(int x, int y, int[][] tile) {
		x = posX * 64;
		y = posY * 32;
		
		int width = tile[0].length / bytesPerPixel;
		int height = tile.length;
		
		for (int h = 0; h < height; h++) {
			for (int w = 0; w < width; w++) {
				if (tile[h][w * bytesPerPixel + 3] != 0) {
					for (int i = 0; i < 4; i++) {
						tileset[y + h][(x+w) * bytesPerPixel + i] = tile[h][w * bytesPerPixel + i];
					}
				}
			}
		}
		
		posX++;
		if (posX % 10 == 0) {
			posX = 0;
			posY++;
		}
	}

	public boolean writeTileset(String filename) {
		
		FileOutputStream fos;
	  	try {
	  		fos = new FileOutputStream(new File(filename));
	  	} catch (FileNotFoundException ex) {
	  		System.out.println("\nCouldn't open " + filename + "!");
	  		return false;
	  	}
	  	
  		BufferedOutputStream outputStream = new BufferedOutputStream(fos);
  		ImageInfo imgInfo = new ImageInfo(tilesetWidth, tilesetHeight, 8, true);
  		PngWriter writer = new PngWriter(outputStream, imgInfo);
  		
  		for (int h=0; h<tilesetHeight; h++) {
  			writer.writeRowInt(tileset[h]);
  		}
  		
  		writer.end();
  		return true;
	}
}
