package pl8.extractor;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;

import ar.com.hjg.pngj.ImageInfo;
import ar.com.hjg.pngj.PngWriter;

public class Tileset_backup {
	
	private final int bytesPerPixel = 4; // one byte per channel of RGBA
	private int spacing; // spacing between two tiles
	private int tilesPerRow; // number of tiles in a row
	private int tileWidth;
	private int tileHeight;
	private int totalWidth;
	private int totalHeight;
	private int[][] tileset;
	
	private int currentPosX = 0;
	private int currentPosY = 0;
	
	public Tileset_backup(int width, int height, int numTiles, int tilesPerRow, int tileSpacing) {
		this.tilesPerRow = tilesPerRow;
		this.spacing = tileSpacing;
		this.tileWidth = width;
		this.tileHeight = height;
		
		int numRows = (int) Math.ceil(numTiles / (float) tilesPerRow);
		this.totalWidth  = width * tilesPerRow + spacing*(tilesPerRow-1);
	  	this.totalHeight = height * numRows + spacing*(numRows-1);
	  	
	  	this.tileset = new int[totalHeight][totalWidth * bytesPerPixel];
	}
	
	public boolean addTile(int[][] tile) {
		if (tile.length != tileHeight || tile[0].length != tileWidth * bytesPerPixel) {
			System.out.println("Error: tile's dimensions do not match dimensions of the tileset!");
			return false;
		}
		
		for (int h = 0; h < tileHeight; h++) {
			for (int w = 0; w < tileWidth * bytesPerPixel; w++) {
				tileset[currentPosY * (tileHeight + spacing) + h][currentPosX * (tileWidth + spacing) * bytesPerPixel + w] = tile[h][w];
			}
		}
		
		currentPosX++;
		if (currentPosX % tilesPerRow == 0) {
			currentPosX = 0;
			currentPosY++;
		}
		
		return true;
	}
	
	public boolean writeTileset(String filename) {
		
		FileOutputStream fos;
	  	try {
	  		fos = new FileOutputStream(new File(filename));
	  	} catch (FileNotFoundException ex) {
	  		System.out.println("\nCouldn't open " + filename + "!");
	  		return false;
	  	}
	  	
  		BufferedOutputStream outputStream = new BufferedOutputStream(fos);
  		ImageInfo imgInfo = new ImageInfo(totalWidth, totalHeight, 8, true);
  		PngWriter writer = new PngWriter(outputStream, imgInfo);
  		
  		for (int h=0; h<totalHeight; h++) {
  			writer.writeRowInt(tileset[h]);
  		}
  		
  		writer.end();
  		return true;
	}
}
